from django import forms


class BaseEditor:

    """Editors should inherit from this. See wiki.editors for examples."""

    # The editor id can be used for conditional testing. If you write your
    # own editor class, you can use the same editor_id as some editor
    editor_id = "plaintext"
    media_admin = ()
    media_frontend = ()

    def get_admin_widget(self, revision=None):
        return forms.Textarea()

    def get_widget(self, revision=None):
        return forms.Textarea()

    class AdminMedia:
        css = {}
        js = ()

    class Media:
        css = {}
        js = ()



from django.apps import AppConfig
from django.utils.translation import gettext_lazy as _


class RedlinksConfig(AppConfig):
    name = "wiki.plugins.redlinks"
    verbose_name = _("Wiki red links")
    label = "wiki_redlinks"
